@@ -1,6 +1,7 @@
 import re
 import time
 import warnings
+import httplib
 
 import requests
 
@@ -47,7 +48,7 @@ class SSEClient(object):
             try:
                 nextchar = next(self.resp.iter_content(decode_unicode=True))
                 self.buf += nextchar
-            except StopIteration:
+            except (StopIteration, httplib.IncompleteRead):
                 time.sleep(self.retry / 1000.0)
                 self._connect()
 
